==> keycloak-model-map-18.0.2-sources.jar: org/keycloak/models/map/user/MapUserFederatedIdentityEntityDelegate.java <==
package org.keycloak.models.map.user;
public class MapUserFederatedIdentityEntityDelegate implements org.keycloak.models.map.user.MapUserFederatedIdentityEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.user.MapUserFederatedIdentityEntity> delegateProvider;
    public MapUserFederatedIdentityEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.user.MapUserFederatedIdentityEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getToken() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.TOKEN).getToken();
    }
    @Override public void setToken(String token) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.TOKEN, token).setToken(token);
    }
    @Override public String getUserId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.USER_ID).getUserId();
    }
    @Override public void setUserId(String userId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.USER_ID, userId).setUserId(userId);
    }
    @Override public String getIdentityProvider() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.IDENTITY_PROVIDER).getIdentityProvider();
    }
    @Override public void setIdentityProvider(String identityProvider) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.IDENTITY_PROVIDER, identityProvider).setIdentityProvider(identityProvider);
    }
    @Override public String getUserName() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.USER_NAME).getUserName();
    }
    @Override public void setUserName(String userName) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.USER_NAME, userName).setUserName(userName);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/user/MapUserFederatedIdentityEntityDelegate.java <==
package org.keycloak.models.map.user;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapUserFederatedIdentityEntityDelegate implements org.keycloak.models.map.user.MapUserFederatedIdentityEntity, org.keycloak.models.map.common.delegate.HasDelegateProvider<org.keycloak.models.map.user.MapUserFederatedIdentityEntity> {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.user.MapUserFederatedIdentityEntity> delegateProvider;
    public MapUserFederatedIdentityEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.user.MapUserFederatedIdentityEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    public org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.user.MapUserFederatedIdentityEntity> getDelegateProvider() {
        return this.delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getToken() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.TOKEN).getToken();
    }
    @Override public void setToken(String token) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.TOKEN, token).setToken(token);
    }
    @Override public String getUserId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.USER_ID).getUserId();
    }
    @Override public void setUserId(String userId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.USER_ID, userId).setUserId(userId);
    }
    @Override public String getIdentityProvider() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.IDENTITY_PROVIDER).getIdentityProvider();
    }
    @Override public void setIdentityProvider(String identityProvider) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.IDENTITY_PROVIDER, identityProvider).setIdentityProvider(identityProvider);
    }
    @Override public String getUserName() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.USER_NAME).getUserName();
    }
    @Override public void setUserName(String userName) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.user.MapUserFederatedIdentityEntityFields.USER_NAME, userName).setUserName(userName);
    }
}
